@@ -1,11 +1,15 @@
 """Tests for nexus reading"""
 import os
 import re
+import warnings
 import unittest
+from copy import deepcopy
 from nexus import NexusReader
 from nexus.reader import GenericHandler, DataHandler, TreeHandler
 
-EXAMPLE_DIR = os.path.join(os.path.split(os.path.dirname(__file__))[0], '../examples')
+EXAMPLE_DIR = os.path.join(os.path.dirname(__file__), '../examples')
+
+warnings.simplefilter("always")
 
 class Test_NexusReader_Core(unittest.TestCase):
     """Test the Core functionality of NexusReader"""
@@ -13,6 +17,21 @@ class Test_NexusReader_Core(unittest.TestCase):
         nex = NexusReader(os.path.join(EXAMPLE_DIR, 'example.nex'))
         assert 'data' in nex.blocks
         assert 'Simon' in nex.blocks['data'].matrix
+    
+    def test_read_gzip_file(self):
+        # first, MAKE a gzip file
+        import gzip
+        from tempfile import NamedTemporaryFile
+        tmp = NamedTemporaryFile(delete=False, suffix=".gz")
+        tmp.close()
+        with open(os.path.join(EXAMPLE_DIR, 'example.nex'), 'rU') as f_in:
+            with gzip.open(tmp.name, 'wb') as f_out:
+                f_out.writelines(f_in)
+        # test it's ok
+        nex = NexusReader(tmp.name)
+        assert 'data' in nex.blocks
+        assert 'Simon' in nex.blocks['data'].matrix
+        os.unlink(tmp.name)        # cleanup
         
     def test_read_string(self):
         handle = open(os.path.join(EXAMPLE_DIR, 'example.nex'))
@@ -143,27 +162,36 @@ class Test_DataHandler_SimpleNexusFormat(unittest.TestCase):
             site_data = self.nex.data.characters[i]
             for taxon, value in site_data.items():
                 assert self.expected[taxon][i] == value
-
-    def test_numcharacters_checking(self):
+    
+    def test_incorrect_dimensions_warnings_ntaxa(self):
         nex = NexusReader()
-        nex.read_string(
-            """Begin data;
-            Dimensions ntax=1 nchar=2;
-            Format datatype=standard symbols="01" gap=-;
-            Matrix
-            Harry              1
-            ;""")
-        assert nex.data.nchar == 1
+        with warnings.catch_warnings(record=True) as w:
+            nex.read_string(
+                """Begin data;
+                Dimensions ntax=5 nchar=1;
+                Format datatype=standard symbols="01" gap=-;
+                Matrix
+                Harry              1
+                ;""")
+            assert len(w) == 1, 'Expected 1 warning, got %r' % w 
+            assert issubclass(w[-1].category, UserWarning)
+            assert "Expected" in str(w[-1].message)
+            assert nex.data.nchar == 1
         
-        nex = NexusReader()
-        nex.read_string(
-            """Begin data;
-            Dimensions ntax=4 nchar=1;
-            Format datatype=standard symbols="01" gap=-;
-            Matrix
-            Harry              11111
-            ;""")
-        assert nex.data.nchar == 5
+    def test_incorrect_dimensions_warnings_nchar(self):
+        with warnings.catch_warnings(record=True) as w:
+            nex = NexusReader()
+            nex.read_string(
+                """Begin data;
+                Dimensions ntax=1 nchar=5;
+                Format datatype=standard symbols="01" gap=-;
+                Matrix
+                Harry              1
+                ;""")
+            assert len(w) == 1, 'Expected 1 warning, got %r' % w 
+            assert issubclass(w[-1].category, UserWarning)
+            assert "Expected" in str(w[-1].message)
+            assert nex.data.nchar == 1
         
 
 class Test_DataHandler_InterleavedNexusFormat(unittest.TestCase):
@@ -370,7 +398,7 @@ class Test_TreeHandler_TranslatedTreefile(unittest.TestCase):
         self.nex.trees.detranslate()
         assert self.nex.trees._been_detranslated == True
         self.nex.trees.detranslate() # should not cause an error
-
+    
     def test_detranslate(self):
         assert self.nex.trees._been_detranslated == False
         self.nex.trees.detranslate()
@@ -379,6 +407,7 @@ class Test_TreeHandler_TranslatedTreefile(unittest.TestCase):
         assert other_tree_file.trees[0] == self.nex.trees[0]
     
 
+
 class Test_TreeHandler_BEAST_Format(unittest.TestCase):
 
     def setUp(self):
@@ -418,8 +447,143 @@ class Test_TreeHandler_BEAST_Format(unittest.TestCase):
             # check if the taxon name is present in the tree...
             assert taxon in self.nex.trees[0], "Expecting taxon %s in tree description" % taxon
         assert self.nex.trees._been_detranslated == True
-    
 
+
+class Test_TreeHandler_translate_regex(unittest.TestCase):
+
+    def setUp(self):
+        th = TreeHandler()
+        self.findall = th._findall_chunks
+
+    def test_tree(self):
+        expected = {
+            0: {
+                'start': '(',
+                'taxon': 'Chris',
+                'comment': None,
+                'branch': None,
+                'end': ','
+            },
+            1: {
+                'start': ',',
+                'taxon': 'Bruce',
+                'comment': None,
+                'branch': None,
+                'end': ')'
+            },
+            2: {
+                'start': ',',
+                'taxon': 'Tom',
+                'comment': None,
+                'branch': None,
+                'end': ')'
+            },
+        }
+        found = self.findall("tree a = ((Chris,Bruce),Tom);")
+        assert len(found) == 3
+        for match in expected:
+            for key in expected[match]:
+                if expected[match][key] != found[match][key]:
+                    assert False, "Expected %s for %s, got %s" % (expected[match][key], key, found[match][key])
+
+
+    def test_tree_digits(self):
+        expected = {
+            0: {
+                'start': '(',
+                'taxon': '1',
+                'comment': None,
+                'branch': None,
+                'end': ','
+            },
+            1: {
+                'start': ',',
+                'taxon': '2',
+                'comment': None,
+                'branch': None,
+                'end': ')'
+            },
+            2: {
+                'start': ',',
+                'taxon': '3',
+                'comment': None,
+                'branch': None,
+                'end': ')'
+            },
+        }
+        found = self.findall("tree a = ((1,2),3);")
+        assert len(found) == 3
+        for match in expected:
+            for key in expected[match]:
+                if expected[match][key] != found[match][key]:
+                    assert False, "Expected %s for %s, got %s" % (expected[match][key], key, found[match][key])
+
+    def test_tree_with_branchlengths(self):
+        expected = {
+            0: {
+                'start': '(',
+                'taxon': '1',
+                'comment': None,
+                'branch': '0.1',
+                'end': ','
+            },
+            1: {
+                'start': ',',
+                'taxon': '2',
+                'comment': None,
+                'branch': '0.2',
+                'end': ')'
+            },
+            2: {
+                'start': ',',
+                'taxon': '3',
+                'comment': None,
+                'branch': '0.3',
+                'end': ')'
+            },
+        }
+        found = self.findall("tree a = ((1:0.1,2:0.2):0.9,3:0.3):0.9;")
+        assert len(found) == 3
+        for match in expected:
+            for key in expected[match]:
+                if expected[match][key] != found[match][key]:
+                    assert False, "Expected %s for %s, got %s" % (expected[match][key], key, found[match][key])
+
+
+    def test_tree_complex(self):
+        expected = {
+            0: {
+                'start': '(',
+                'taxon': '1',
+                'comment': '[&var=1]',
+                'branch': '0.1',
+                'end': ','
+            },
+            1: {
+                'start': ',',
+                'taxon': '2',
+                'comment': '[&var=2]',
+                'branch': '0.2',
+                'end': ')'
+            },
+            2: {
+                'start': ',',
+                'taxon': '3',
+                'comment': '[&var=4]',
+                'branch': '0.3',
+                'end': ')'
+            },
+        }
+        found = self.findall("tree a = ((1:[&var=1]0.1,2:[&var=2]0.2):[&var=3]0.9,3:[&var=4]0.3):[&var=5]0.9;")
+        assert len(found) == 3
+        for match in expected:
+            for key in expected[match]:
+                if expected[match][key] != found[match][key]:
+                    assert False, "Expected %s for %s, got %s" % (expected[match][key], key, found[match][key])
+
+    
+        
+    
 class Test_TreeHandler__detranslate_tree(unittest.TestCase):
     
     def test_no_change(self):
@@ -458,87 +622,6 @@ class Test_TreeHandler__detranslate_tree(unittest.TestCase):
         assert trans == newtree, "Unable to correctly detranslate a BEAST tree"
 
 
-class test_Regression_whitespace_in_matrix(unittest.TestCase):
-    """Regression: Test that leading whitespace in a data matrix is parsed ok"""
-    def test_regression(self):
-        nex = NexusReader()
-        nex.read_string("""
-        #NEXUS 
-    
-        Begin data;
-            Dimensions ntax=4 nchar=2;
-                                Format datatype=standard symbols="01" gap=-;
-                Matrix
-        Harry              00
-                Simon              01
-                        Betty              10
-                                    Louise 11
-            ;
-        End;
-        """)
-        assert nex.blocks['data'].nchar == 2
-        assert nex.blocks['data'].matrix['Harry'] == ['0', '0']
-        assert nex.blocks['data'].matrix['Simon'] == ['0', '1']
-        assert nex.blocks['data'].matrix['Betty'] == ['1', '0']
-        assert nex.blocks['data'].matrix['Louise'] == ['1', '1']
-        
-    
-
-class test_badchars_quoted_in_taxaname(unittest.TestCase):
-    def test_regressions(self):
-        nex = NexusReader()
-        nex.read_string("""
-        #NEXUS
-
-        Begin trees;
-        	Translate
-        		1 MANGIC_Bugan,
-        		2 MANGIC_Paliu,
-        		3 MANGIC_Mang,
-        		4 PALAUNGWA_Danaw,
-        		5 'PALAUNGWA_De.Ang'
-            ;
-            tree 1 = (1,2,3,4,5);
-        """)
-        # did we get a tree block?
-        assert 'trees' in nex.blocks
-        # did we find 3 trees?
-        assert len(nex.blocks['trees'].trees) == 1 == nex.blocks['trees'].ntrees
-        # did we get the translation parsed properly.
-        assert nex.trees.was_translated == True
-        assert len(nex.trees.translators) == 5 # 5 taxa in example trees
-        # check last entry
-        assert nex.trees.translators['5'] == 'PALAUNGWA_De.Ang'
-        # check detranslate
-        nex.trees.detranslate()
-        assert '(MANGIC_Bugan,MANGIC_Paliu,MANGIC_Mang,PALAUNGWA_Danaw,PALAUNGWA_De.Ang)' in nex.trees[0]
-    
-
-class Test_TreeHandler_Regression_RandomAPETrees(unittest.TestCase):
-    def test_regression(self):
-        nex = NexusReader()
-        nex.read_string(
-        """
-        #NEXUS
-        [R-package APE, Mon Apr  4 13:30:05 2011]
-
-        BEGIN TAXA;
-        	DIMENSIONS NTAX = 5;
-        	TAXLABELS
-        		t5
-        		t2
-        		t3
-        		t4
-        		t1
-        	;
-        END;
-        BEGIN TREES;
-        	TREE * UNTITLED = [&R] (((t5:0.8158685302,(t2:0.3804786047,t3:0.9345045802):0.9044287337):0.2170910214,t4:0.5744336853):0.9122619091,t1:0.2579922327);
-        	TREE * UNTITLED = [&R] (((t1:0.7530630897,t5:0.00636632205):0.8808043781,t2:0.967890667):0.861689928,(t3:0.795280267,t4:0.4398460181):0.2651306945);
-        END;
-        """
-        )
-        assert nex.trees.ntrees == 2
 
 if __name__ == '__main__':
     unittest.main()
