@@ -1,7 +1,7 @@
 import os
 import unittest
 
-from nexus import NexusReader, NexusWriter, NexusFormatException
+from nexus import NexusReader, NexusFormatException
 from nexus.tools import check_for_valid_NexusReader
 
 EXAMPLE_DIR = os.path.join(os.path.dirname(__file__), '../../examples')
